@@ -3,11 +3,11 @@ var examples =
     [ "ex_access.c", "ex_access_8c-example.html", null ],
     [ "ex_async.c", "ex_async_8c-example.html", null ],
     [ "ex_call_center.c", "ex_call_center_8c-example.html", null ],
-    [ "ex_config.c", "ex_config_8c-example.html", null ],
     [ "ex_cursor.c", "ex_cursor_8c-example.html", null ],
     [ "ex_encrypt.c", "ex_encrypt_8c-example.html", null ],
     [ "ex_extending.c", "ex_extending_8c-example.html", null ],
     [ "ex_extractor.c", "ex_extractor_8c-example.html", null ],
+    [ "ex_file_system.c", "ex_file_system_8c-example.html", null ],
     [ "ex_hello.c", "ex_hello_8c-example.html", null ],
     [ "ex_log.c", "ex_log_8c-example.html", null ],
     [ "ex_pack.c", "ex_pack_8c-example.html", null ],
