@@ -10,9 +10,11 @@ var functions_func =
     [ "i", "functions_func_i.html", null ],
     [ "j", "functions_func_j.html", null ],
     [ "l", "functions_func_l.html", null ],
+    [ "m", "functions_func_m.html", null ],
     [ "n", "functions_func_n.html", null ],
     [ "o", "functions_func_o.html", null ],
     [ "p", "functions_func_p.html", null ],
+    [ "q", "functions_func_q.html", null ],
     [ "r", "functions_func_r.html", null ],
     [ "s", "functions_func_s.html", null ],
     [ "t", "functions_func_t.html", null ],
