@@ -2,6 +2,8 @@ var group__wt__java =
 [
     [ "AsyncOp", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html", [
       [ "AsyncOp", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a39f23dd4fbc75463ffb11ad4c72290ec", null ],
+      [ "_java_init", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a8361b50c47b9179ce5814aa991d2a5f3", null ],
+      [ "_java_raw", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a115f7a071ed8f7a74210a9e61c619035", null ],
       [ "compact", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#adb4a7d8e5e3c32ddc21a3115f01fb1d3", null ],
       [ "delete", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#aa55c5e5c8b271eed5c819102c6983c36", null ],
       [ "get_key_wrap", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a4a3caa9aec9c75403b414dba75fc4d16", null ],
@@ -33,7 +35,6 @@ var group__wt__java =
       [ "getValueString", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a4f90e2de9e9d7f7ed202a7b6c771d3e4", null ],
       [ "insert", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a26a055ea016382d8d6c3343bde12465b", null ],
       [ "insert_wrap", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a48a7bc4bac3b6db7ef1dad071c0c9c50", null ],
-      [ "java_init", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#ac471b645c23b2cd0442cdbc06a473040", null ],
       [ "putKeyByte", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a779a66ea992bcc9e0aa203d316b85450", null ],
       [ "putKeyByteArray", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#afc6ce2a8b7039f11bc11f84ea2885242", null ],
       [ "putKeyByteArray", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a42cdd99e86a8c983242d0c117415acdc", null ],
@@ -56,6 +57,7 @@ var group__wt__java =
       [ "search_wrap", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#ade974445c314fc23f59ad8c607d4ef96", null ],
       [ "update", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a1228739dd75066c8b03907b033c80c7c", null ],
       [ "update_wrap", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a4df7a1508b8b3e684b8ec37fba19f301", null ],
+      [ "javaRaw", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#aa7088d2dfa4bf670a5801de44329ef96", null ],
       [ "keyFormat", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#ad1df733204cd4324d3bee18dff06f798", null ],
       [ "keyPacker", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#a11a892de4cdd6cd9cb63cddf145c6d31", null ],
       [ "keyUnpacker", "classcom_1_1wiredtiger_1_1db_1_1_async_op.html#acf345795a87279fdd88b17ccc1e1a0a3", null ],
@@ -66,21 +68,29 @@ var group__wt__java =
     ] ],
     [ "Connection", "classcom_1_1wiredtiger_1_1db_1_1_connection.html", [
       [ "Connection", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a9f3713033d9e9a1a84f4670da907c55d", null ],
+      [ "_java_init", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#aad6794c4baf107e2d0a735c80f9c8e52", null ],
       [ "async_flush", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a6ca4a22fe3c729d68cd56c5abb047498", null ],
       [ "async_new_op", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a76c8444703541803fab4bc54606136ed", null ],
       [ "close", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a2458441ed6301620ef4db71f3ef5c47c", null ],
       [ "configure_method", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a1b9848afb4bfe4b790579490e6e2263c", null ],
+      [ "debug_info", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#af0d653b71e7fede300bea53337323087", null ],
       [ "delete", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a0e8af34ebdff2b71b682095ed085cebe", null ],
       [ "get_home", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#ad52f0d0c36bcedfa2214f233f3ee020a", null ],
       [ "is_new", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a7ba72791fba4a03984c0d9b8faca1284", null ],
-      [ "java_init", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a0ba0590fcde7f51b426a5ceec5013581", null ],
       [ "load_extension", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a1c404c400a9873926810241ad0997a4a", null ],
       [ "open_session", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#ad03cfc01de34342ab8c76934accb8745", null ],
+      [ "query_timestamp", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a77d25707d0ce76799a8b8d61f84b6a97", null ],
       [ "reconfigure", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a5e67d007427eb9a0b1c749b8c85468e2", null ],
+      [ "rollback_to_stable", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#aa133f587176b4510a753e1dc950fa5fc", null ],
+      [ "set_timestamp", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a84403030d0ef4f986544dda57498a1b4", null ],
       [ "swigCMemOwn", "classcom_1_1wiredtiger_1_1db_1_1_connection.html#a31658ee0e58784dd785b7226b1309476", null ]
     ] ],
     [ "Cursor", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html", [
       [ "Cursor", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a5ea9b69aa679f51e6e01753d1f23d483", null ],
+      [ "_java_init", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a22e023eac397937cb9b3c07d7bfa4427", null ],
+      [ "_java_raw", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#ab243b9fe9af7f3b50614182f11fde35e", null ],
+      [ "_new_check_modify", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a5ecca39cfd1a7df153ec7d609783f2c2", null ],
+      [ "_new_check_modify_list", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a88034fa1336ddda0ba693a3a0aec0e61", null ],
       [ "close", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#adc0e5bd37f139ba544f9a95191767bde", null ],
       [ "compare", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a4c91a82815161b5283036bd7653ed577", null ],
       [ "compare_wrap", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#aeaf553d1dd2fb4a74b7afce430b05f31", null ],
@@ -115,7 +125,8 @@ var group__wt__java =
       [ "getValueString", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#aec7c9271b8f4cdb04f006cedbc2e2a76", null ],
       [ "insert", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a3ab2c9b3c69a6653af8ce51147f1b3b2", null ],
       [ "insert_wrap", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#aa499ea066ca8d887654d65f4db59b3f9", null ],
-      [ "java_init", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#aa97e663267549dc5d3a146d43dc1cfda", null ],
+      [ "modify", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a347f47ece41c10b6d11adcdeea214c4b", null ],
+      [ "modify_wrap", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a6a6d182cb786fce8a9f8bdbf07e3df10", null ],
       [ "next", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a948b125f9a495a5970c54518293fa519", null ],
       [ "next_wrap", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#ad3dc0989618c3cde0566f96ce8250802", null ],
       [ "prev", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#ac1cad29955c05140e672149d0db7f81a", null ],
@@ -139,6 +150,7 @@ var group__wt__java =
       [ "reconfigure", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a2219b90a6028093404c907ff30db346c", null ],
       [ "remove", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a07781c4a66856b9e2aeb30e520335060", null ],
       [ "remove_wrap", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a8be6c66d2e7d05835b85686ea9f8abe8", null ],
+      [ "reserve", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a8a7d5faef93f695956492564ad13b92b", null ],
       [ "reset", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a3e53838f94cdf00798c1a50c86bf1c50", null ],
       [ "reset_wrap", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#a1d05d97e259395b9efd8b9289b8336e9", null ],
       [ "search", "classcom_1_1wiredtiger_1_1db_1_1_cursor.html#ada3437e64263221f33a8f713eba72148", null ],
@@ -157,7 +169,10 @@ var group__wt__java =
     ] ],
     [ "Session", "classcom_1_1wiredtiger_1_1db_1_1_session.html", [
       [ "Session", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a76afc8fe00e0b542b8424fd8b8fb5b84", null ],
+      [ "_java_init", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a849ad022f16375699c7dd625b80cc7e8", null ],
+      [ "alter", "classcom_1_1wiredtiger_1_1db_1_1_session.html#aabeba4de10b95083dae3c73b7172e4a7", null ],
       [ "begin_transaction", "classcom_1_1wiredtiger_1_1db_1_1_session.html#abda8ddc193622bedbe6fba26e061405a", null ],
+      [ "breakpoint", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a14615b126a4824d04b7126b69ce5db6a", null ],
       [ "checkpoint", "classcom_1_1wiredtiger_1_1db_1_1_session.html#ae8a3a848702a49b9c3cb8e1ed1c1afd3", null ],
       [ "close", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a575d56d4413369b3db49bfeac3ff4caa", null ],
       [ "commit_transaction", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a707380a753afffb89b3195c16938ce8f", null ],
@@ -166,11 +181,13 @@ var group__wt__java =
       [ "delete", "classcom_1_1wiredtiger_1_1db_1_1_session.html#abd928363a1ed03e95e27c287efaa6363", null ],
       [ "drop", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a08aa0622c56a5839b7c38f420b1f2a85", null ],
       [ "getConnection", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a2f267cf49f92a76b4bad57015a05ba88", null ],
-      [ "java_init", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a06bf69bf9e0ec46cbe72ec014b32360d", null ],
       [ "join", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a75ec87d13d61c38312f6097e86470b22", null ],
       [ "log_flush", "classcom_1_1wiredtiger_1_1db_1_1_session.html#ac8790893082bc6ca34ca288008971944", null ],
-      [ "log_printf", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a094ae49ac5f0533817961284c89b8327", null ],
+      [ "log_printf", "classcom_1_1wiredtiger_1_1db_1_1_session.html#acf3ea0aa8ef9a33416409fa8b8da80ae", null ],
       [ "open_cursor", "classcom_1_1wiredtiger_1_1db_1_1_session.html#adc61edbe05447e070a2d0729bd36a084", null ],
+      [ "prepare_transaction", "classcom_1_1wiredtiger_1_1db_1_1_session.html#aa824eb8055b405d362997a1ccdb3ea1a", null ],
+      [ "query_timestamp", "classcom_1_1wiredtiger_1_1db_1_1_session.html#ad09f01b6d71809614567c84110d95cc1", null ],
+      [ "rebalance", "classcom_1_1wiredtiger_1_1db_1_1_session.html#ae8e72b903d72a3ca1f1a0dd019c186d7", null ],
       [ "reconfigure", "classcom_1_1wiredtiger_1_1db_1_1_session.html#ab26e9fa8589c722544049adae0e70ad9", null ],
       [ "rename", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a2acb7e037b0d4bf9c8d812d264376465", null ],
       [ "reset", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a2ce840af5f1ffff040dd097a2a3065e4", null ],
@@ -178,6 +195,7 @@ var group__wt__java =
       [ "salvage", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a4687837f13f03699d9c295fdd4380398", null ],
       [ "snapshot", "classcom_1_1wiredtiger_1_1db_1_1_session.html#aa9c59ebe27793654d9a6206f28344809", null ],
       [ "strerror", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a0d3664f22568a5b36bece98592cb6ea4", null ],
+      [ "timestamp_transaction", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a8a7c42b78d550fd51a955cd336c39e43", null ],
       [ "transaction_pinned_range", "classcom_1_1wiredtiger_1_1db_1_1_session.html#aed31a501ee163947de5a82f2b31b03b9", null ],
       [ "transaction_sync", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a65ecc08c6b9d27bb108dd5bdac93b8a3", null ],
       [ "truncate", "classcom_1_1wiredtiger_1_1db_1_1_session.html#a2c58845dfd2f75cc3935185c12d29329", null ],
