@@ -20,11 +20,13 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 ".html",
-"classcom_1_1wiredtiger_1_1db_1_1_pack_output_stream.html#a2bda605ed3c4c4b85a52e145ea809f61",
-"ex_pack_8c-example.html",
-"group__wt.html#ga7fa6ef6ad4ec854de76565ebce34cede",
-"schema_lang_java.html#schema_examples_lang_java",
-"upgrading.html#version_13"
+"classcom_1_1wiredtiger_1_1db_1_1_pack_input_stream.html",
+"devdoc-schema.html#schema_create",
+"group__wt.html#ga2c96ee16874c2beb1bb96979648f5b21",
+"group__wt.html#ga8bacfcb1989b797fcc50f12ea7696ecc",
+"group__wt.html#gafddb1885f74ab7abf0de9c9ae0630cb9",
+"struct_w_t___e_n_c_r_y_p_t_o_r.html#abad5447ebeb99d06b9024df435cffc26",
+"upgrading.html#version_260"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
