@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Public Domain 2014-2015 MongoDB, Inc.
+# Public Domain 2014-2019 MongoDB, Inc.
 # Public Domain 2008-2014 WiredTiger, Inc.
 #
 # This is free and unencumbered software released into the public domain.
@@ -29,7 +29,7 @@
 import os
 import suite_random
 import wiredtiger, wtscenario, wttest
-from wtscenario import check_scenarios
+from wtscenario import make_scenarios
 
 try:
     # Windows does not getrlimit/setrlimit so we must catch the resource
@@ -79,7 +79,7 @@ class tabconfig:
             elif format == 'i':
                 keys.append(rev)
             elif format == 'r':
-                keys.append(long(i+1))
+                keys.append(self.recno(i+1))
         return keys
 
     def gen_values(self, i):
@@ -133,7 +133,7 @@ class tabconfig:
         rand = suite_random.suite_random(ncolumns, totalindices)
 
         # Initially, all indices get one column from the collist.
-        # Overlaps are allowed.  Then probalistically, add some
+        # Overlaps are allowed.  Then probabalistically, add some
         # more columns.
         for idx in self.idxlist:
             prob = 1.0
@@ -151,7 +151,6 @@ class tabconfig:
                         idx.formats += self.valueformats[colno - self.nkeys]
                 prob *= 0.5
 
-
 class cgconfig:
     """
     Configuration for a column group used in the test.
@@ -219,6 +218,9 @@ class test_schema03(wttest.WiredTigerTestCase):
     - between each step, whether to close/reopen the connection
     """
 
+    # Boost cache size and number of sessions for this test
+    conn_config = 'cache_size=100m,session_max=1000'
+
     ################################################################
     # These three variables can be altered to help generate
     # and pare down failing test cases.
@@ -246,7 +248,7 @@ class test_schema03(wttest.WiredTigerTestCase):
     # but boost it up to this limit anyway.
     OPEN_FILE_LIMIT = 1000
 
-    restart_scenarios = check_scenarios([('table', dict(s_restart=['table'],P=0.3)),
+    restart_scenarios = [('table', dict(s_restart=['table'],P=0.3)),
                          ('colgroup0', dict(s_restart=['colgroup0'],P=0.3)),
                          ('index0', dict(s_restart=['index0'],P=0.3)),
                          ('colgroup1', dict(s_restart=['colgroup1'],P=0.3)),
@@ -256,7 +258,7 @@ class test_schema03(wttest.WiredTigerTestCase):
                          ('populate1', dict(s_restart=['populate1'],P=0.3)),
                          ('ipop', dict(s_restart=['index0','populate0'],P=0.3)),
                          ('all', dict(s_restart=['table','colgroup0','index0','colgroup1','index1','populate0','index2','populate1'],P=1.0)),
-    ])
+    ]
 
     ntable_scenarios = wtscenario.quick_scenarios('s_ntable',
         [1,2,5,8], [1.0,0.4,0.5,0.5])
@@ -269,11 +271,10 @@ class test_schema03(wttest.WiredTigerTestCase):
     table_args_scenarios = wtscenario.quick_scenarios('s_extra_table_args',
         ['', ',type=file', ',type=lsm'], [0.5, 0.3, 0.2])
 
-    all_scenarios = wtscenario.multiply_scenarios('_', restart_scenarios, ntable_scenarios, ncolgroup_scenarios, nindex_scenarios, idx_args_scenarios, table_args_scenarios)
-
-    # Prune the scenarios according to the probabilities given above.
-    scenarios = wtscenario.prune_scenarios(all_scenarios, 30)
-    scenarios = wtscenario.number_scenarios(scenarios)
+    scenarios = wtscenario.make_scenarios(
+        restart_scenarios, ntable_scenarios, ncolgroup_scenarios,
+        nindex_scenarios, idx_args_scenarios, table_args_scenarios,
+        prune=30)
 
     # Note: the set can be reduced here for debugging, e.g.
     # scenarios = scenarios[40:44]
@@ -297,12 +298,6 @@ class test_schema03(wttest.WiredTigerTestCase):
         resource.setrlimit(resource.RLIMIT_NOFILE, newlimit)
         super(test_schema03, self).setUp()
 
-    def setUpConnectionOpen(self, dir):
-        conn = wiredtiger.wiredtiger_open(dir,
-            'create,cache_size=100m,session_max=1000')
-        self.pr(`conn`)
-        return conn
-
     def tearDown(self):
         super(test_schema03, self).tearDown()
         resource.setrlimit(resource.RLIMIT_NOFILE, self.origFileLimit)
@@ -320,7 +315,7 @@ class test_schema03(wttest.WiredTigerTestCase):
         if self.SHOW_PYTHON:
             if self.SHOW_PYTHON_ONLY_TABLE == None or self.current_table in self.SHOW_PYTHON_ONLY_TABLE:
                 if self.SHOW_PYTHON_ONLY_SCEN == None or self.scenario_number in self.SHOW_PYTHON_ONLY_SCEN:
-                    print '        ' + s
+                    print('        ' + s)
 
     def join_names(self, sep, prefix, list):
         return sep.join([prefix + str(val) for val in list])
@@ -335,14 +330,14 @@ class test_schema03(wttest.WiredTigerTestCase):
 
     def finished_step(self, name):
         if self.s_restart == name:
-            print "  # Reopening connection at step: " + name
+            print("  # Reopening connection at step: " + name)
             self.reopen_conn()
 
     def test_schema(self):
         rand = suite_random.suite_random()
         if self.SHOW_PYTHON:
-            print '  ################################################'
-            print '  # Running scenario ' + str(self.scenario_number)
+            print('  ################################################')
+            print('  # Running scenario ' + str(self.scenario_number))
 
         ntables = self.s_ntable
 
@@ -436,8 +431,8 @@ class test_schema03(wttest.WiredTigerTestCase):
             self.show_python("self.session.create('table:" + tc.tablename + "', '" + config + "')")
             self.session.create("table:" + tc.tablename, config)
 
-            tc.columns_for_groups(range(tc.nkeys, tc.nkeys + tc.nvalues))
-            tc.columns_for_indices(range(0, tc.nkeys + tc.nvalues))
+            tc.columns_for_groups(list(range(tc.nkeys, tc.nkeys + tc.nvalues)))
+            tc.columns_for_indices(list(range(0, tc.nkeys + tc.nvalues)))
 
         self.finished_step('table')
 
@@ -466,7 +461,7 @@ class test_schema03(wttest.WiredTigerTestCase):
         for tc in tabconfigs:
             self.current_table = tc.tableidx
             max = rand.rand_range(0, self.nentries)
-            self.populate(tc, xrange(0, max))
+            self.populate(tc, list(range(0, max)))
 
         self.finished_step('populate0')
 
@@ -481,7 +476,7 @@ class test_schema03(wttest.WiredTigerTestCase):
         # populate second batch
         for tc in tabconfigs:
             self.current_table = tc.tableidx
-            self.populate(tc, xrange(tc.nentries, self.nentries))
+            self.populate(tc, list(range(tc.nentries, self.nentries)))
 
         self.finished_step('populate1')
 
