@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Public Domain 2014-2015 MongoDB, Inc.
+# Public Domain 2014-2019 MongoDB, Inc.
 # Public Domain 2008-2014 WiredTiger, Inc.
 #
 # This is free and unencumbered software released into the public domain.
@@ -29,6 +29,7 @@
 # WiredTigerTestCase
 #   parent class for all test cases
 #
+from __future__ import print_function
 
 # If unittest2 is available, use it in preference to (the old) unittest
 try:
@@ -37,15 +38,16 @@ except ImportError:
     import unittest
 
 from contextlib import contextmanager
-import os, re, shutil, sys, time, traceback
-import wtscenario
-import wiredtiger
+import glob, os, re, shutil, sys, time, traceback
+import wiredtiger, wtscenario
 
 def shortenWithEllipsis(s, maxlen):
     if len(s) > maxlen:
         s = s[0:maxlen-3] + '...'
     return s
 
+_python3 = (sys.version_info >= (3, 0, 0))
+
 class CapturedFd(object):
     """
     CapturedFd encapsulates a file descriptor (e.g. 1 or 2) that is diverted
@@ -93,6 +95,8 @@ class CapturedFd(object):
         file.  If there is, raise it as a test failure.
         This is generally called after 'release' is called.
         """
+        if WiredTigerTestCase._ignoreStdout:
+            return
         if self.file != None:
             self.file.flush()
         filesize = os.path.getsize(self.filename)
@@ -102,7 +106,7 @@ class CapturedFd(object):
                                      ' unexpected ' + self.desc +
                                      ', contains:\n"' + contents + '"')
             testcase.fail('unexpected ' + self.desc + ', contains: "' +
-                      shortenWithEllipsis(contents,100) + '"')
+                      contents + '"')
         self.expectpos = filesize
 
     def checkAdditional(self, testcase, expect):
@@ -134,16 +138,55 @@ class CapturedFd(object):
                           gotstr + '"')
         self.expectpos = os.path.getsize(self.filename)
 
+class TestSuiteConnection(object):
+    def __init__(self, conn, connlist):
+        connlist.append(conn)
+        self._conn = conn
+        self._connlist = connlist
+
+    def close(self, config=''):
+        self._connlist.remove(self._conn)
+        return self._conn.close(config)
+
+    # Proxy everything except what we explicitly define to the
+    # wrapped connection
+    def __getattr__(self, attr):
+        if attr in self.__dict__:
+            return getattr(self, attr)
+        else:
+            return getattr(self._conn, attr)
+
+# Just like a list of strings, but with a convenience function
+class ExtensionList(list):
+    skipIfMissing = False
+    def extension(self, dirname, name, extarg=None):
+        if name != None and name != 'none':
+            ext = '' if extarg == None else '=' + extarg
+            self.append(dirname + '/' + name + ext)
 
 class WiredTigerTestCase(unittest.TestCase):
     _globalSetup = False
     _printOnceSeen = {}
+
+    # conn_config can be overridden to add to basic connection configuration.
+    # Can be a string or a callable function or lambda expression.
     conn_config = ''
 
+    # session_config can be overridden to add to basic session configuration.
+    # Can be a string or a callable function or lambda expression.
+    session_config = ''
+
+    # conn_extensions can be overridden to add a list of extensions to load.
+    # Each entry is a string (directory and extension name) and optional config.
+    # Example:
+    #    conn_extensions = ('extractors/csv_extractor',
+    #                       'test/fail_fs={allow_writes=100}')
+    conn_extensions = ()
+
     @staticmethod
     def globalSetup(preserveFiles = False, useTimestamp = False,
-                    gdbSub = False, verbose = 1, dirarg = None,
-                    longtest = False):
+                    gdbSub = False, lldbSub = False, verbose = 1, builddir = None, dirarg = None,
+                    longtest = False, ignoreStdout = False):
         WiredTigerTestCase._preserveFiles = preserveFiles
         d = 'WT_TEST' if dirarg == None else dirarg
         if useTimestamp:
@@ -152,11 +195,14 @@ class WiredTigerTestCase(unittest.TestCase):
         os.makedirs(d)
         wtscenario.set_long_run(longtest)
         WiredTigerTestCase._parentTestdir = d
+        WiredTigerTestCase._builddir = builddir
         WiredTigerTestCase._origcwd = os.getcwd()
-        WiredTigerTestCase._resultfile = open(os.path.join(d, 'results.txt'), "w", 0)  # unbuffered
+        WiredTigerTestCase._resultfile = open(os.path.join(d, 'results.txt'), "w", 1)  # line buffered
         WiredTigerTestCase._gdbSubprocess = gdbSub
+        WiredTigerTestCase._lldbSubprocess = lldbSub
         WiredTigerTestCase._longtest = longtest
         WiredTigerTestCase._verbose = verbose
+        WiredTigerTestCase._ignoreStdout = ignoreStdout
         WiredTigerTestCase._dupout = os.dup(sys.stdout.fileno())
         WiredTigerTestCase._stdout = sys.stdout
         WiredTigerTestCase._stderr = sys.stderr
@@ -190,48 +236,138 @@ class WiredTigerTestCase(unittest.TestCase):
         # help distinguish tests.
         scen = ''
         if hasattr(self, 'scenario_number') and hasattr(self, 'scenario_name'):
-            scen = '(scenario ' + str(self.scenario_number) + \
-                   ': ' + self.scenario_name + ')'
+            scen = ' -s ' + str(self.scenario_number) + \
+                   ' (' + self.scenario_name + ')'
         return self.simpleName() + scen
 
+    def shortDesc(self):
+        ret_str = ''
+        if hasattr(self, 'scenario_number'):
+            ret_str = ' -s ' + str(self.scenario_number)
+        return self.simpleName() + ret_str
+
     def simpleName(self):
         return "%s.%s.%s" %  (self.__module__,
                               self.className(), self._testMethodName)
 
-    # Can be overridden
-    def setUpConnectionOpen(self, dir):
-        conn = wiredtiger.wiredtiger_open(dir,
-            'create,error_prefix="%s",%s' % (self.shortid(), self.conn_config))
-        self.pr(`conn`)
+    def buildDirectory(self):
+        return self._builddir
+
+    # Return the wiredtiger_open extension argument for
+    # any needed shared library.
+    def extensionsConfig(self):
+        exts = self.conn_extensions
+        if hasattr(exts, '__call__'):
+            exts = ExtensionList()
+            self.conn_extensions(exts)
+        result = ''
+        extfiles = {}
+        skipIfMissing = False
+        if hasattr(exts, 'skip_if_missing'):
+            skipIfMissing = exts.skip_if_missing
+        for ext in exts:
+            extconf = ''
+            if '=' in ext:
+                splits = ext.split('=', 1)
+                ext = splits[0]
+                extconf = '=' + splits[1]
+            splits = ext.split('/')
+            if len(splits) != 2:
+                raise Exception(self.shortid() +
+                    ": " + ext +
+                    ": extension is not named <dir>/<name>")
+            libname = splits[1]
+            dirname = splits[0]
+            pat = os.path.join(WiredTigerTestCase._builddir, 'ext',
+                dirname, libname, '.libs', 'libwiredtiger_*.so')
+            filenames = glob.glob(pat)
+            if len(filenames) == 0:
+                if skipIfMissing:
+                    self.skipTest('extension "' + ext + '" not built')
+                    continue
+                else:
+                    raise Exception(self.shortid() +
+                        ": " + ext +
+                        ": no extensions library found matching: " + pat)
+            elif len(filenames) > 1:
+                raise Exception(self.shortid() +
+                    ": " + ext +
+                    ": multiple extensions libraries found matching: " + pat)
+            complete = '"' + filenames[0] + '"' + extconf
+            if ext in extfiles:
+                if extfiles[ext] != complete:
+                    raise Exception(self.shortid() +
+                        ": non-matching extension arguments in " +
+                        str(exts))
+            else:
+                extfiles[ext] = complete
+        if len(extfiles) != 0:
+            result = ',extensions=[' + ','.join(list(extfiles.values())) + ']'
+        return result
+
+    # Can be overridden, but first consider setting self.conn_config
+    # or self.conn_extensions
+    def setUpConnectionOpen(self, home):
+        self.home = home
+        config = self.conn_config
+        if hasattr(config, '__call__'):
+            config = self.conn_config()
+        config += self.extensionsConfig()
+        # In case the open starts additional threads, flush first to
+        # avoid confusion.
+        sys.stdout.flush()
+        conn_param = 'create,error_prefix="%s",%s' % (self.shortid(), config)
+        try:
+            conn = self.wiredtiger_open(home, conn_param)
+        except wiredtiger.WiredTigerError as e:
+            print("Failed wiredtiger_open: dir '%s', config '%s'" % \
+                (home, conn_param))
+            raise e
+        self.pr(repr(conn))
         return conn
 
-    # Can be overridden
+    # Replacement for wiredtiger.wiredtiger_open that returns
+    # a proxied connection that knows to close it itself at the
+    # end of the run, unless it was already closed.
+    def wiredtiger_open(self, home=None, config=''):
+        conn = wiredtiger.wiredtiger_open(home, config)
+        return TestSuiteConnection(conn, self._connections)
+
+    # Can be overridden, but first consider setting self.session_config
     def setUpSessionOpen(self, conn):
-        return conn.open_session(None)
+        config = self.session_config
+        if hasattr(config, '__call__'):
+            config = self.session_config()
+        return conn.open_session(config)
 
     # Can be overridden
-    def close_conn(self):
+    def close_conn(self, config=''):
         """
         Close the connection if already open.
         """
         if self.conn != None:
-            self.conn.close()
+            self.conn.close(config)
             self.conn = None
 
-    def open_conn(self):
+    def open_conn(self, directory=".", config=None):
         """
         Open the connection if already closed.
         """
         if self.conn == None:
-            self.conn = self.setUpConnectionOpen(".")
+            if config != None:
+                self._old_config = self.conn_config
+                self.conn_config = config
+            self.conn = self.setUpConnectionOpen(directory)
+            if config != None:
+                self.conn_config = self._old_config
             self.session = self.setUpSessionOpen(self.conn)
 
-    def reopen_conn(self):
+    def reopen_conn(self, directory=".", config=None):
         """
         Reopen the connection.
         """
         self.close_conn()
-        self.open_conn()
+        self.open_conn(directory, config)
 
     def setUp(self):
         if not hasattr(self.__class__, 'wt_ntests'):
@@ -242,14 +378,19 @@ class WiredTigerTestCase(unittest.TestCase):
             self.testsubdir = self.className() + '.' + str(self.__class__.wt_ntests)
         self.testdir = os.path.join(WiredTigerTestCase._parentTestdir, self.testsubdir)
         self.__class__.wt_ntests += 1
+        self.starttime = time.time()
         if WiredTigerTestCase._verbose > 2:
             self.prhead('started in ' + self.testdir, True)
+        # tearDown needs connections list, set it here in case the open fails.
+        self._connections = []
         self.origcwd = os.getcwd()
         shutil.rmtree(self.testdir, ignore_errors=True)
         if os.path.exists(self.testdir):
             raise Exception(self.testdir + ": cannot remove directory")
         os.makedirs(self.testdir)
         os.chdir(self.testdir)
+        with open('testname.txt', 'w+') as namefile:
+            namefile.write(str(self) + '\n')
         self.fdSetUp()
         # tearDown needs a conn field, set it here in case the open fails.
         self.conn = None
@@ -260,19 +401,39 @@ class WiredTigerTestCase(unittest.TestCase):
             self.tearDown()
             raise
 
+    # Used as part of tearDown determining if there is an error.
+    def list2reason(self, result, fieldname):
+        exc_list = getattr(result, fieldname, None)
+        if exc_list and exc_list[-1][0] is self:
+            return exc_list[-1][1]
+
     def tearDown(self):
-        excinfo = sys.exc_info()
-        passed = (excinfo == (None, None, None))
-        if passed:
-            skipped = False
-        else:
-            skipped = (excinfo[0] == unittest.SkipTest)
+        # This approach works for all our support Python versions and
+        # is suggested by one of the answers in:
+        # https://stackoverflow.com/questions/4414234/getting-pythons-unittest-results-in-a-teardown-method
+        if hasattr(self, '_outcome'):  # Python 3.4+
+            result = self.defaultTestResult()  # these 2 methods have no side effects
+            self._feedErrorsToResult(result, self._outcome.errors)
+        else:  # Python 3.2 - 3.3 or 3.0 - 3.1 and 2.7
+            result = getattr(self, '_outcomeForDoCleanups', self._resultForDoCleanups)
+        error = self.list2reason(result, 'errors')
+        failure = self.list2reason(result, 'failures')
+        passed = not error and not failure
+
         self.pr('finishing')
 
-        try:
-            self.close_conn()
-        except:
-            pass
+        # Close all connections that weren't explicitly closed.
+        # Connections left open (as a result of a test failure)
+        # can result in cascading errors.  We also make sure
+        # self.conn is on the list of active connections.
+        if not self.conn in self._connections:
+            self._connections.append(self.conn)
+        for conn in self._connections:
+            try:
+                conn.close()
+            except:
+                pass
+        self._connections = []
 
         try:
             self.fdTearDown()
@@ -284,16 +445,27 @@ class WiredTigerTestCase(unittest.TestCase):
             # always get back to original directory
             os.chdir(self.origcwd)
 
+        # Make sure no read-only files or directories were left behind
+        os.chmod(self.testdir, 0o777)
+        for root, dirs, files in os.walk(self.testdir):
+            for d in dirs:
+                os.chmod(os.path.join(root, d), 0o777)
+            for f in files:
+                os.chmod(os.path.join(root, f), 0o666)
+        self.pr('passed=' + str(passed))
+
         # Clean up unless there's a failure
-        if (passed or skipped) and not WiredTigerTestCase._preserveFiles:
+        if passed and not WiredTigerTestCase._preserveFiles:
             shutil.rmtree(self.testdir, ignore_errors=True)
         else:
             self.pr('preserving directory ' + self.testdir)
 
-        if not passed and not skipped:
-            print "ERROR in " + str(self)
+        elapsed = time.time() - self.starttime
+        if elapsed > 0.001 and WiredTigerTestCase._verbose >= 2:
+            print("%s: %.2f seconds" % (str(self), elapsed))
+        if not passed:
+            print("ERROR in " + str(self))
             self.pr('FAIL')
-            self.prexception(excinfo)
             self.pr('preserving directory ' + self.testdir)
         if WiredTigerTestCase._verbose > 2:
             self.prhead('TEST COMPLETED')
@@ -352,6 +524,59 @@ class WiredTigerTestCase(unittest.TestCase):
             with self.expectedStderr(message):
                 self.assertRaises(exceptionType, expr)
 
+    def assertRaisesException(self, exceptionType, expr,
+        exceptionString=None, optional=False):
+        """
+        Like TestCase.assertRaises(), with some additional options.
+        If the exceptionString argument is used, the exception's string
+        must match it, or its pattern if the string starts and ends with
+        a slash. If optional is set, then no assertion occurs if the
+        exception doesn't occur.
+        Returns true if the assertion is raised.
+        """
+        raised = False
+        try:
+            expr()
+        except BaseException as err:
+            self.pr('Exception raised shown as string: "' + \
+                    str(err) + '"')
+            if not isinstance(err, exceptionType):
+                self.fail('Exception of incorrect type raised, got type: ' + \
+                    str(type(err)))
+            if exceptionString != None:
+                # Match either a pattern or an exact string.
+                fail = False
+                self.pr('Expecting string msg: ' + exceptionString)
+                if len(exceptionString) > 2 and \
+                  exceptionString[0] == '/' and exceptionString[-1] == '/' :
+                      if re.search(exceptionString[1:-1], str(err)) == None:
+                        fail = True
+                elif exceptionString != str(err):
+                        fail = True
+                if fail:
+                    self.fail('Exception with incorrect string raised, got: "' + \
+                        str(err) + '" Expected: ' + exceptionString)
+            raised = True
+        if not raised and not optional:
+            self.fail('no assertion raised')
+        return raised
+
+    def raisesBusy(self, expr):
+        """
+        Execute the expression, returning true if a 'Resource busy' exception
+        is raised, returning false if no exception is raised. Some systems
+        report 'Device or resource busy', allow either.
+        Any other exception raises a test suite failure.
+        """
+        return self.assertRaisesException(wiredtiger.WiredTigerError, \
+            expr, exceptionString='/[Rr]esource busy/', optional=True)
+
+    def assertTimestampsEqual(self, ts1, ts2):
+        """
+        TestCase.assertEqual() for timestamps
+        """
+        self.assertEqual(int(ts1, 16), int(ts2, 16))
+
     def exceptionToStderr(self, expr):
         """
         Used by assertRaisesHavingMessage to convert an expression
@@ -360,7 +585,7 @@ class WiredTigerTestCase(unittest.TestCase):
         """
         try:
             expr()
-        except BaseException, err:
+        except BaseException as err:
             sys.stderr.write('Exception: ' + str(err))
             raise
 
@@ -395,6 +620,15 @@ class WiredTigerTestCase(unittest.TestCase):
         msg = '**** ' + myname + ' HAS A KNOWN LIMITATION: ' + name + ' ****'
         self.printOnce(msg)
 
+    def databaseCorrupted(self, directory = None):
+        """
+        Mark this test as having a corrupted database by creating a
+        DATABASE_CORRUPTED file in the home directory.
+        """
+        if directory == None:
+            directory = self.home
+        open(os.path.join(directory, "DATABASE_CORRUPTED"), "a").close()
+
     @staticmethod
     def printVerbose(level, message):
         if level <= WiredTigerTestCase._verbose:
@@ -408,7 +642,7 @@ class WiredTigerTestCase(unittest.TestCase):
 
     @staticmethod
     def prout(s):
-        os.write(WiredTigerTestCase._dupout, s + '\n')
+        os.write(WiredTigerTestCase._dupout, str.encode(s + '\n'))
 
     def pr(self, s):
         """
@@ -433,6 +667,30 @@ class WiredTigerTestCase(unittest.TestCase):
         traceback.print_exception(excinfo[0], excinfo[1], excinfo[2], None, WiredTigerTestCase._resultfile)
         WiredTigerTestCase._resultfile.write('\n')
 
+    def recno(self, i):
+        """
+        return a recno key
+        """
+        if _python3:
+            return i
+        else:
+            return long(i)
+
+    def ord_byte(self, b):
+        """
+        return the 'ord' of a single byte.
+        In Python2 a set of bytes is represented as a string, and a single
+        byte is a string of length one.  In Python3, bytes are an array of
+        ints, so no explicit ord() call is needed.
+        """
+        if _python3:
+            return b
+        else:
+            return ord(b)
+
+    def is_python3(self):
+        return _python3
+
     # print directly to tty, useful for debugging
     def tty(self, message):
         WiredTigerTestCase.tty(message)
@@ -457,7 +715,6 @@ class WiredTigerTestCase(unittest.TestCase):
     def className(self):
         return self.__class__.__name__
 
-
 def longtest(description):
     """
     Used as a function decorator, for example, @wttest.longtest("description").
@@ -492,4 +749,4 @@ def runsuite(suite, parallel):
 
 def run(name='__main__'):
     result = runsuite(unittest.TestLoader().loadTestsFromName(name), False)
-    sys.exit(not result.wasSuccessful())
+    sys.exit(0 if result.wasSuccessful() else 1)
